@@ -12,14 +12,12 @@ use URI;
 Readonly::Array our @EXPORT_OK => qw(check_location check_uri check_url
 	check_urn);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub check_location {
 	my ($self, $key) = @_;
 
-	if (! exists $self->{$key}) {
-		return;
-	}
+	_check_key($self, $key) && return;
 
 	my $value = $self->{$key};
 	my $uri = URI->new($value);
@@ -39,9 +37,7 @@ sub check_location {
 sub check_uri {
 	my ($self, $key) = @_;
 
-	if (! exists $self->{$key}) {
-		return;
-	}
+	_check_key($self, $key) && return;
 
 	my $value = $self->{$key};
 	if (! is_uri($value)) {
@@ -56,9 +52,7 @@ sub check_uri {
 sub check_url {
 	my ($self, $key) = @_;
 
-	if (! exists $self->{$key}) {
-		return;
-	}
+	_check_key($self, $key) && return;
 
 	my $value = $self->{$key};
 	my $uri = URI->new($value);
@@ -74,9 +68,7 @@ sub check_url {
 sub check_urn {
 	my ($self, $key) = @_;
 
-	if (! exists $self->{$key}) {
-		return;
-	}
+	_check_key($self, $key) && return;
 
 	my $value = $self->{$key};
 	my $uri = URI->new($value);
@@ -89,6 +81,16 @@ sub check_urn {
 	return;
 }
 
+sub _check_key {
+	my ($self, $key) = @_;
+
+	if (! exists $self->{$key} || ! defined $self->{$key}) {
+		return 1;
+	}
+
+	return 0;
+}
+
 1;
 
 __END__
@@ -397,12 +399,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2024 Michal Josef Špaček
+© 2024-2025 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
